@@ -1,4 +1,3 @@
-from portalcomponentscg.logs import LogsCriticalErros, LogsErros
 
 
 class CGExceptionsErros(Exception):
@@ -27,7 +26,6 @@ class ErrorJson(CGExceptionsRequestsErros):
         super().__init__(self.message)
 
     def __str__(self):
-        LogsErros([self.component, self.message])
         return f'{self.component} -> {self.message}'
 
 
@@ -39,7 +37,6 @@ class ErrorCredentials(CGExceptionsErros):
         super().__init__(self.message)
 
     def __str__(self):
-        LogsErros([self.component, self.message])
         return f'{self.component} -> {self.message}'
 
 
@@ -53,7 +50,6 @@ class BackEndConnectionError(CGExceptionsRequestsErros):
         super().__init__(self.message, suggestion)
 
     def __str__(self):
-        LogsCriticalErros(self.message)
         return f'{self.suggestion} -> {self.message}'
 
 
@@ -67,8 +63,6 @@ class IntranetConnectionError(CGExceptionsRequestsErros):
         super().__init__(self.message, suggestion)
 
     def __str__(self):
-        LogsCriticalErros(self.message)
-
         return f'{self.suggestion} -> {self.message}'
 
 
@@ -83,6 +77,4 @@ class ErrorConnectionRDS(CGExceptionsRDS):
         super().__init__(self.message)
 
     def __str__(self):
-        LogsCriticalErros([self.component, self.message])
-
         return f'{self.component} -> {self.message}'
